@@ -284,7 +284,7 @@ impl IntoPy<PyObject> for PyEinsumArgs {
 #[pymethods]
 impl Einsum {
     #[new]
-    #[args(args = "*", out_axes, name)]
+    #[pyo3(signature=(*args, out_axes, name = None))]
     fn new_py(
         args: Vec<(CircuitRc, EinsumAxes)>,
         out_axes: EinsumAxes,
@@ -331,7 +331,7 @@ impl Einsum {
     }
 
     #[staticmethod]
-    #[args(nodes = "*", name)]
+    #[pyo3(signature=(string, *nodes, name = None))]
     pub fn from_einsum_string(
         string: &str,
         nodes: Vec<CircuitRc>,
@@ -345,7 +345,7 @@ impl Einsum {
     }
 
     #[staticmethod]
-    #[args(nodes = "*", name)]
+    #[pyo3(signature=(string, *nodes, name = None))]
     pub fn from_fancy_string(
         string: &str,
         nodes: Vec<CircuitRc>,
@@ -359,7 +359,7 @@ impl Einsum {
     }
 
     #[staticmethod]
-    #[args(nodes = "*", name)]
+    #[pyo3(signature=(spec, *nodes, name = None))]
     pub fn from_spec_py(
         spec: EinsumSpec,
         nodes: Vec<CircuitRc>,
@@ -399,7 +399,7 @@ impl Einsum {
         .unwrap()
     }
     #[staticmethod]
-    #[args(nodes = "*", name = "None")]
+    #[pyo3(signature=(*nodes, name = None))]
     pub fn elementwise_broadcasted(nodes: Vec<CircuitRc>, name: Option<Name>) -> Result<Einsum> {
         let out_shape = broadcast_shapes(
             &nodes
@@ -448,7 +448,7 @@ impl Einsum {
     }
 
     #[staticmethod]
-    #[args(nodes = "*", name = "None", out_axes_permutation)]
+    #[pyo3(signature=(*nodes, name = None, out_axes_permutation = None))]
     pub fn new_outer_product(
         nodes: Vec<CircuitRc>,
         name: Option<Name>,
@@ -583,7 +583,7 @@ impl Add {
 #[pymethods]
 impl Add {
     #[new]
-    #[args(nodes = "*", name = "None")]
+    #[pyo3(signature=(*nodes, name = None))]
     fn new_py(nodes: Vec<CircuitRc>, name: Option<Name>) -> PyResult<PyClassInitializer<Self>> {
         let out = Self::try_new(nodes, name)?;
 
@@ -615,7 +615,7 @@ impl Add {
     }
 
     #[staticmethod]
-    #[args(nodes_and_weights = "*", use_1_weights = "false", name = "None")]
+    #[pyo3(signature=(*nodes_and_weights, use_1_weights = false, name = None))]
     pub fn from_weighted_nodes(
         nodes_and_weights: Vec<(CircuitRc, f64)>,
         use_1_weights: bool,
@@ -1381,7 +1381,7 @@ impl CircuitNodeAutoName for Concat {
 #[pymethods]
 impl Concat {
     #[new]
-    #[args(nodes = "*", axis, name = "None")]
+    #[pyo3(signature=(*nodes, axis, name = None))]
     fn new_py(
         nodes: Vec<CircuitRc>,
         axis: i64,
@@ -1408,7 +1408,7 @@ impl Concat {
     }
 
     #[staticmethod]
-    #[args(nodes = "*", axis, name = "None")]
+    #[pyo3(signature=(*nodes, axis, name = None))]
     pub fn stack(nodes: Vec<CircuitRc>, axis: i64, name: Option<Name>) -> Result<Self> {
         let axis = Self::convert_axis(&nodes, axis, true)?;
         let to_cat = nodes
@@ -1850,7 +1850,7 @@ impl ConvPaddingShorthand {
 #[pymethods]
 impl Conv {
     #[new]
-    #[args(groups = "1", padding = "ConvPaddingShorthand::Single(0)")]
+    #[pyo3(signature=(input, filter, stride, padding = ConvPaddingShorthand::Single(0), name = None))]
     fn new_py(
         input: CircuitRc,
         filter: CircuitRc,
