@@ -123,19 +123,18 @@ impl Array {
 #[pymethods]
 impl Array {
     #[new]
-    #[args(name = "None")]
+    #[pyo3(signature=(value, name = None))]
     fn py_new(value: Tensor, name: Option<Name>) -> Result<PyClassInitializer<Self>> {
         Ok(Array::try_new(value, name)?.into_init())
     }
 
     #[staticmethod]
-    #[pyo3(name = "randn")]
-    #[args(
-        shape = "*",
-        name = "None",
-        device_dtype = "TorchDeviceDtypeOp::TENSOR_DEFAULT",
-        seed = "None"
-    )]
+    #[pyo3(name = "randn", signature=(
+        *shape,
+        name = None,
+        device_dtype = TorchDeviceDtypeOp::TENSOR_DEFAULT,
+        seed = None
+    ))]
     pub fn randn_full(
         shape: Shape,
         name: Option<Name>,
@@ -177,7 +176,7 @@ impl Array {
             )
         })
     }
-    #[args(force = "false")]
+    #[pyo3(signature=(force = false))]
     pub fn save_rrfs(&self, force: bool) -> Result<String> {
         save_tensor(self.value.clone(), force).map(|_| self.tensor_hash_base16())
     }
@@ -332,7 +331,7 @@ impl Scalar {
 #[pymethods]
 impl Scalar {
     #[new]
-    #[args(shape = "sv![]")]
+    #[pyo3(signature=(value, shape = sv![], name = None))]
     fn py_new(value: f64, shape: Shape, name: Option<Name>) -> PyClassInitializer<Self> {
         Self::new(value, shape, name).into_init()
     }
