@@ -31,7 +31,7 @@ use crate::{
 #[pyfunction]
 #[pyo3(name = "expand_node")]
 pub fn expand_node_py(circuit: CircuitRc, inputs: Vec<CircuitRc>) -> Result<CircuitRc> {
-    expand_node(circuit, &inputs, |_, _, _| {
+    expand_node(circuit, &inputs, &mut |_, _, _| {
         bail!("fancy module expanding not supported via python expand node")
     })
 }
@@ -114,7 +114,7 @@ impl_eq_by_big_hash!(ReplaceMapRc);
 pub fn expand_node(
     circuit: CircuitRc,
     inputs: &Vec<CircuitRc>,
-    rerun_with_extra_replacements: impl FnOnce(
+    rerun_with_extra_replacements: &mut dyn FnMut(
         CircuitRc,
         HashMap<CircuitRc, CircuitRc>,
         usize,
@@ -1018,7 +1018,7 @@ impl<F: ReplaceForExpand> ReplaceExpander<F> {
             .map(|(c, rep)| self_.replace_expand_with_map(c, &rep))
             .collect::<Result<_>>()?;
 
-        expand_node(circuit, &new_children, |c, rep, child_idx| {
+        expand_node(circuit, &new_children, &mut |c, rep, child_idx| {
             self_.replace_expand_with_map(c, &per_child_extra[child_idx].extend_into(rep))
         })
     }
