@@ -719,7 +719,8 @@ simple_from!(|x: GeneralFunctionPowSpec| -> GeneralFunctionSpec { GeneralFunctio
 
 /// NOTE: expanding/batching doesn't nicely handle this (in the way it nicely handles add)
 /// More generally, we have poor general func support for expand/batch
-#[pyfunction(special_case_ones = "true")]
+#[pyfunction]
+#[pyo3(signature=(shapes, special_case_ones = true))]
 pub fn get_shape_info_broadcast(
     shapes: Vec<Shape>,
     special_case_ones: bool,
@@ -945,7 +946,8 @@ impl SpecTrait for GeneralFunctionMultinomialSpec {
     }
 }
 
-#[pyfunction(replacement = "true", name = "None")]
+#[pyfunction]
+#[pyo3(signature=(probs, seed, shape, replacement = true, name = None))]
 pub fn multinomial(
     probs: CircuitRc,
     seed: CircuitRc,
@@ -1397,7 +1399,7 @@ impl CircuitNodeAutoName for GeneralFunction {
 #[pymethods]
 impl GeneralFunction {
     #[new]
-    #[args(nodes = "*", spec, name = "None")]
+    #[pyo3(signature=(*nodes, spec, name = None))]
     fn new_py(
         nodes: Vec<CircuitRc>,
         spec: GeneralFunctionSpec,
@@ -1409,7 +1411,7 @@ impl GeneralFunction {
     }
 
     #[staticmethod]
-    #[args(nodes = "*", spec_name, name = "None")]
+    #[pyo3(signature=(*nodes, parse_string, name = None))]
     pub fn new_from_parse(
         nodes: Vec<CircuitRc>,
         parse_string: String,
@@ -1427,14 +1429,14 @@ impl GeneralFunction {
     }
 
     #[staticmethod]
-    #[args(nodes = "*", spec_name, name = "None")]
+    #[pyo3(signature=(*nodes, spec_name, name = None))]
     pub fn new_by_name(nodes: Vec<CircuitRc>, spec_name: Name, name: Option<Name>) -> Result<Self> {
         Self::new_by_name_op(nodes, spec_name, name)?
             .ok_or(ConstructError::UnknownGeneralFunction { spec_name }.into())
     }
 
     #[staticmethod]
-    #[args(nodes = "*", spec_name, name = "None")]
+    #[pyo3(signature=(*nodes, spec_name, name = None))]
     pub fn new_by_name_op(
         nodes: Vec<CircuitRc>,
         spec_name: Name,
@@ -1552,7 +1554,7 @@ impl GeneralFunction {
     }
 
     #[staticmethod]
-    #[args(nodes = "*", path, name = "None")]
+    #[pyo3(signature=(*nodes, path, name = None))]
     pub fn new_by_path(nodes: Vec<CircuitRc>, path: String, name: Option<Name>) -> Result<Self> {
         let locator = PyClassLocator::parse(&path)?;
 
@@ -1566,12 +1568,15 @@ impl GeneralFunction {
     }
 
     #[staticmethod]
-    #[args(
-        batch_x = "false",
-        batch_index = "true",
-        check_index_ints = "true",
-        name = "None"
-    )]
+    #[pyo3(signature=(
+        x,
+        index,
+        index_dim,
+        batch_x = false,
+        batch_index = true,
+        check_index_ints = true,
+        name = None
+    ))]
     pub fn gen_index(
         x: CircuitRc,
         index: CircuitRc,
@@ -1592,7 +1597,7 @@ impl GeneralFunction {
     }
 
     #[staticmethod]
-    #[args(check_index_ints = "true", name = "None")]
+    #[pyo3(signature=(x, index, index_dim, x_non_batch_dims, check_index_ints = true, name = None))]
     pub fn explicit_index(
         x: CircuitRc,
         index: CircuitRc,
@@ -1608,11 +1613,12 @@ impl GeneralFunction {
     }
 
     #[staticmethod]
-    #[args(
-        input_required_compatibility = "Default::default()",
-        output = "Default::default()",
-        name = "None"
-    )]
+    #[pyo3(signature=(
+        x,
+        input_required_compatibility = Default::default(),
+        output = Default::default(),
+        name = None
+    ))]
     pub fn new_cast(
         x: CircuitRc,
         input_required_compatibility: TorchDeviceDtypeOp,
@@ -1680,20 +1686,20 @@ impl Default for GeneralFunctionSpecTester {
 #[pymethods]
 impl GeneralFunctionSpecTester {
     #[new]
-    #[args(
-        samples_per_batch_dims = "GeneralFunctionSpecTester::default().samples_per_batch_dims",
-        base_shapes_samples = "GeneralFunctionSpecTester::default().base_shapes_samples",
-        min_frac_successful = "GeneralFunctionSpecTester::default().min_frac_successful",
-        min_frac_checked_batch = "GeneralFunctionSpecTester::default().min_frac_checked_batch",
-        start_num_inputs = "GeneralFunctionSpecTester::default().start_num_inputs",
-        end_num_inputs = "GeneralFunctionSpecTester::default().end_num_inputs",
-        start_ndim = "GeneralFunctionSpecTester::default().start_ndim",
-        end_ndim = "GeneralFunctionSpecTester::default().end_ndim",
-        start_shape_num = "GeneralFunctionSpecTester::default().start_shape_num",
-        end_shape_num = "GeneralFunctionSpecTester::default().end_shape_num",
-        test_with_rand = "GeneralFunctionSpecTester::default().test_with_rand",
-        randn_size_cap = "GeneralFunctionSpecTester::default().randn_size_cap"
-    )]
+    #[pyo3(signature=(
+        samples_per_batch_dims = GeneralFunctionSpecTester::default().samples_per_batch_dims,
+        base_shapes_samples = GeneralFunctionSpecTester::default().base_shapes_samples,
+        min_frac_successful = GeneralFunctionSpecTester::default().min_frac_successful,
+        min_frac_checked_batch = GeneralFunctionSpecTester::default().min_frac_checked_batch,
+        start_num_inputs = GeneralFunctionSpecTester::default().start_num_inputs,
+        end_num_inputs = GeneralFunctionSpecTester::default().end_num_inputs,
+        start_ndim = GeneralFunctionSpecTester::default().start_ndim,
+        end_ndim = GeneralFunctionSpecTester::default().end_ndim,
+        start_shape_num = GeneralFunctionSpecTester::default().start_shape_num,
+        end_shape_num = GeneralFunctionSpecTester::default().end_shape_num,
+        test_with_rand = GeneralFunctionSpecTester::default().test_with_rand,
+        randn_size_cap = GeneralFunctionSpecTester::default().randn_size_cap
+    ))]
     fn new(
         samples_per_batch_dims: usize,
         base_shapes_samples: usize,
@@ -1724,7 +1730,7 @@ impl GeneralFunctionSpecTester {
         }
     }
 
-    #[args(shapes_must_be_valid = "false")]
+    #[pyo3(signature=(spec, shapes, shapes_must_be_valid = false))]
     pub fn test_from_shapes(
         &self,
         spec: GeneralFunctionSpec,
