@@ -2186,22 +2186,22 @@ impl PyCircuitBase {
         print_circuit_stats(&self.0)
     }
 
-    #[args(autoname_disabled = "true")]
+    #[pyo3(signature=(autoname_disabled=true))]
     fn with_autoname_disabled(&self, autoname_disabled: bool) -> CircuitRc {
         self.0.clone().with_autoname_disabled(autoname_disabled)
     }
 
-    #[args(options = "Default::default()")]
+    #[pyo3(signature=(options = Default::default()))]
     fn repr(&self, options: PrintOptions) -> Result<String> {
         options.repr((*self.0).crc())
     }
 
-    #[args(options = "Default::default()")]
+    #[pyo3(signature=(options = Default::default()))]
     fn print(&self, options: PrintOptionsBase) -> Result<()> {
         options.print(vec![(*self.0).crc()])
     }
 
-    #[args(options = "Default::default()")]
+    #[pyo3(signature=(options = Default::default()))]
     fn print_html(&self, options: PrintHtmlOptions) -> Result<()> {
         options.print(vec![(*self.0).crc()])
     }
@@ -2409,11 +2409,13 @@ impl PyCircuitBase {
     pub fn into_var(&self) -> Option<Var> {
         self.0.clone().c().into()
     }
-    #[args(
-        cache_transform = "true",
-        cache_update = "true",
-        fancy_validate = "DEFAULT_FANCY_VALIDATE"
-    )]
+    #[pyo3(signature=(
+        matcher,
+        transform,
+        cache_transform = true,
+        cache_update = true,
+        fancy_validate = DEFAULT_FANCY_VALIDATE
+    ))]
     pub fn update(
         &self,
         matcher: OpaqueIterativeMatcherVal,
@@ -2430,7 +2432,7 @@ impl PyCircuitBase {
             fancy_validate,
         )
     }
-    #[args(fancy_validate = "DEFAULT_FANCY_VALIDATE")]
+    #[pyo3(signature=(matcher, fancy_validate = DEFAULT_FANCY_VALIDATE))]
     pub fn get(
         &self,
         matcher: OpaqueIterativeMatcherVal,
@@ -2439,7 +2441,7 @@ impl PyCircuitBase {
         matcher.get(self.0.clone(), fancy_validate)
     }
 
-    #[args(fancy_validate = "DEFAULT_FANCY_VALIDATE")]
+    #[pyo3(signature=(matcher, fancy_validate = DEFAULT_FANCY_VALIDATE))]
     pub fn get_unique_op(
         &self,
         matcher: OpaqueIterativeMatcherVal,
@@ -2448,7 +2450,7 @@ impl PyCircuitBase {
         matcher.get_unique_op(self.0.clone(), fancy_validate)
     }
 
-    #[args(fancy_validate = "DEFAULT_FANCY_VALIDATE")]
+    #[pyo3(signature=(matcher, fancy_validate = DEFAULT_FANCY_VALIDATE))]
     pub fn get_unique(
         &self,
         matcher: OpaqueIterativeMatcherVal,
