@@ -567,7 +567,7 @@ pub fn py_get_free_symbols(circuit: CircuitRc) -> Vec<Symbol> {
 #[pymethods]
 impl ModuleSpec {
     #[new]
-    #[args(check_all_inputs_used = "true", check_unique_arg_names = "true")]
+    #[pyo3(signature=(circuit, arg_specs, check_all_inputs_used = true, check_unique_arg_names = true))]
     pub fn new(
         circuit: CircuitRc,
         arg_specs: Vec<ModuleArgSpec>,
@@ -635,7 +635,7 @@ impl ModuleSpec {
     }
 
     #[staticmethod]
-    #[args(check_unique_arg_names = "true")]
+    #[pyo3(signature=(circuit, check_unique_arg_names = true))]
     pub fn new_free_symbols(circuit: CircuitRc, check_unique_arg_names: bool) -> Result<Self> {
         let arg_specs = get_free_symbols(&circuit)
             .iter()
@@ -652,7 +652,7 @@ impl ModuleSpec {
     }
 
     #[staticmethod]
-    #[args(check_all_inputs_used = "true", check_unique_arg_names = "true")]
+    #[pyo3(signature=(circuit, arg_specs, check_all_inputs_used = true, check_unique_arg_names = true))]
     pub fn new_extract(
         circuit: CircuitRc,
         arg_specs: Vec<(CircuitRc, ModuleArgSpec)>,
@@ -821,11 +821,12 @@ impl ModuleArgSpec {
 #[pymethods]
 impl ModuleArgSpec {
     #[new]
-    #[args(
-        batchable = "Self::default().batchable",
-        expandable = "Self::default().expandable",
-        ban_non_symbolic_size_expand = "Self::default().ban_non_symbolic_size_expand"
-    )]
+    #[pyo3(signature=(
+        symbol,
+        batchable = Self::default().batchable,
+        expandable = Self::default().expandable,
+        ban_non_symbolic_size_expand = Self::default().ban_non_symbolic_size_expand
+    ))]
     fn new(
         symbol: Symbol,
         batchable: bool,
@@ -840,11 +841,12 @@ impl ModuleArgSpec {
         }
     }
     #[staticmethod]
-    #[args(
-        batchable = "Self::default().batchable",
-        expandable = "Self::default().expandable",
-        ban_non_symbolic_size_expand = "false", // I think this is right default for this?
-    )]
+    #[pyo3(signature=(
+        circuit,
+        batchable = Self::default().batchable,
+        expandable = Self::default().expandable,
+        ban_non_symbolic_size_expand = false, // I think this is right default for this?
+    ))]
     pub fn just_name_shape(
         circuit: CircuitRc,
         batchable: bool,
@@ -1126,7 +1128,7 @@ impl CircuitNodeAutoName for Module {
 #[pymethods]
 impl Module {
     #[new]
-    #[args(name = "None", kwargs = "**")]
+    #[pyo3(signature=(spec, name = None, **kwargs))]
     fn new_py(
         spec: ModuleSpec,
         name: Option<Name>,
@@ -1136,18 +1138,18 @@ impl Module {
     }
 
     #[staticmethod]
-    #[args(nodes = "*", name = "None")]
+    #[pyo3(signature=(spec, *nodes, name = None))]
     fn new_flat(spec: ModuleSpec, nodes: Vec<CircuitRc>, name: Option<Name>) -> Result<Self> {
         Self::try_new(nodes, spec, name)
     }
 
     /// TODO: fancier renaming technology?
     #[pyo3(name = "substitute")]
-    #[args(
-        name_prefix = "None",
-        name_suffix = "None",
-        use_self_name_as_prefix = "false"
-    )]
+    #[pyo3(signature=(
+        name_prefix = None,
+        name_suffix = None,
+        use_self_name_as_prefix = false
+    ))]
     pub fn substitute_py(
         &self,
         name_prefix: Option<String>,
@@ -1158,7 +1160,7 @@ impl Module {
         Ok(self.substitute(name_prefix, name_suffix))
     }
 
-    #[args(prefix = "None", suffix = "None", use_self_name_as_prefix = "false")]
+    #[pyo3(signature=(prefix = None, suffix = None, use_self_name_as_prefix = false))]
     pub fn rename_on_replaced_path(
         &self,
         prefix: Option<String>,
