@@ -100,16 +100,16 @@ pub(super) fn get_reference_circuits(
 
 #[pymethods]
 impl Parser {
-    #[args(
-        reference_circuits = "Parser::default().reference_circuits",
-        reference_circuits_by_name = "vec![]",
-        tensors_as_random = "Parser::default().tensors_as_random",
-        tensors_as_random_device_dtype = "Parser::default().tensors_as_random_device_dtype",
-        allow_hash_with_random = "Parser::default().allow_hash_with_random",
-        on_repeat_check_info_same = "Parser::default().on_repeat_check_info_same",
-        module_check_all_inputs_used = "Parser::default().module_check_all_inputs_used",
-        module_check_unique_arg_names = "Parser::default().module_check_unique_arg_names"
-    )]
+    #[pyo3(signature=(
+        reference_circuits = Parser::default().reference_circuits,
+        reference_circuits_by_name = vec![],
+        tensors_as_random = Parser::default().tensors_as_random,
+        tensors_as_random_device_dtype = Parser::default().tensors_as_random_device_dtype,
+        allow_hash_with_random = Parser::default().allow_hash_with_random,
+        on_repeat_check_info_same = Parser::default().on_repeat_check_info_same,
+        module_check_all_inputs_used = Parser::default().module_check_all_inputs_used,
+        module_check_unique_arg_names = Parser::default().module_check_unique_arg_names
+    ))]
     #[new]
     pub fn new(
         reference_circuits: HashMap<Name, CircuitRc>,
