@@ -403,26 +403,26 @@ pub fn op_traversal_per(
 impl PrintOptions {
     // new function for rust and python (in rust for validation)
     #[new]
-    #[args(
-        bijection = "PrintOptions::default().bijection",
-        reference_circuits = "PrintOptions::default().reference_circuits",
-        reference_circuits_by_name = "vec![]",
-        shape_only_when_necessary = "PrintOptions::default().shape_only_when_necessary",
-        traversal = "None",
-        leaves_on_top = "PrintOptions::default().leaves_on_top",
-        arrows = "PrintOptions::default().arrows",
-        force_use_serial_numbers = "PrintOptions::default().force_use_serial_numbers",
-        number_leaves = "PrintOptions::default().number_leaves",
-        colorer = "None",
-        comment_arg_names = "PrintOptions::default().comment_arg_names",
-        commenters = "PrintOptions::default().commenters",
-        sync_tensors = "PrintOptions::default().sync_tensors",
-        seen_children_same_line = "PrintOptions::default().seen_children_same_line",
-        only_child_below = "PrintOptions::default().only_child_below",
-        tensor_index_literal = "PrintOptions::default().tensor_index_literal",
-        show_all_named_axes = "PrintOptions::default().show_all_named_axes",
-        tensor_save_dir = "None"
-    )]
+    #[pyo3(signature=(
+        bijection = PrintOptions::default().bijection,
+        reference_circuits = PrintOptions::default().reference_circuits,
+        reference_circuits_by_name = vec![],
+        shape_only_when_necessary = PrintOptions::default().shape_only_when_necessary,
+        traversal = None,
+        leaves_on_top = PrintOptions::default().leaves_on_top,
+        arrows = PrintOptions::default().arrows,
+        force_use_serial_numbers = PrintOptions::default().force_use_serial_numbers,
+        number_leaves = PrintOptions::default().number_leaves,
+        colorer = None,
+        comment_arg_names = PrintOptions::default().comment_arg_names,
+        commenters = PrintOptions::default().commenters,
+        sync_tensors = PrintOptions::default().sync_tensors,
+        seen_children_same_line = PrintOptions::default().seen_children_same_line,
+        only_child_below = PrintOptions::default().only_child_below,
+        tensor_index_literal = PrintOptions::default().tensor_index_literal,
+        show_all_named_axes = PrintOptions::default().show_all_named_axes,
+        tensor_save_dir = None
+    ))]
     pub fn new(
         bijection: bool,
         reference_circuits: HashMap<CircuitRc, Name>,
@@ -475,25 +475,25 @@ impl PrintOptions {
         Ok(result)
     }
 
-    #[args(
-        bijection = "Default::default()",
-        reference_circuits = "Default::default()",
-        shape_only_when_necessary = "Default::default()",
-        traversal = "Default::default()",
-        leaves_on_top = "Default::default()",
-        arrows = "Default::default()",
-        force_use_serial_numbers = "Default::default()",
-        number_leaves = "Default::default()",
-        colorer = "Default::default()",
-        comment_arg_names = "Default::default()",
-        commenters = "Default::default()",
-        sync_tensors = "Default::default()",
-        seen_children_same_line = "Default::default()",
-        only_child_below = "Default::default()",
-        tensor_index_literal = "Default::default()",
-        show_all_named_axes = "Default::default()",
-        tensor_save_dir = "Default::default()"
-    )]
+    #[pyo3(signature=(
+        bijection = Default::default(),
+        reference_circuits = Default::default(),
+        shape_only_when_necessary = Default::default(),
+        traversal = Default::default(),
+        leaves_on_top = Default::default(),
+        arrows = Default::default(),
+        force_use_serial_numbers = Default::default(),
+        number_leaves = Default::default(),
+        colorer = Default::default(),
+        comment_arg_names = Default::default(),
+        commenters = Default::default(),
+        sync_tensors = Default::default(),
+        seen_children_same_line = Default::default(),
+        only_child_below = Default::default(),
+        tensor_index_literal = Default::default(),
+        show_all_named_axes = Default::default(),
+        tensor_save_dir = Default::default()
+    ))]
     pub fn evolve(
         &self,
         bijection: MaybeNotSet<bool>,
@@ -566,7 +566,7 @@ impl PrintOptions {
     }
 
     #[staticmethod]
-    #[args(end_depth = "DEFAULT_END_DEPTH")]
+    #[pyo3(signature=(end_depth = DEFAULT_END_DEPTH))]
     pub fn debug_default(end_depth: Option<usize>) -> PrintOptions {
         Self {
             bijection: false,
@@ -631,8 +631,7 @@ impl PrintOptions {
         Ok(())
     }
 
-    #[pyo3(name = "print")]
-    #[args(circuits = "*")]
+    #[pyo3(name = "print", signature=(*circuits))]
     pub fn print_circuits(&self, circuits: Vec<CircuitRc>) -> Result<()> {
         python_println!("{}", self.repr_circuits(circuits)?);
         Ok(())
@@ -775,8 +774,7 @@ impl PrintOptions {
             _ => "".to_owned(),
         })
     }
-    #[pyo3(name = "repr")]
-    #[args(circuits = "*")]
+    #[pyo3(name = "repr", signature=(*circuits))]
     pub fn repr_circuits(&self, circuits: Vec<CircuitRc>) -> Result<String> {
         let mut seen_hashes = HashMap::default();
 
@@ -1056,8 +1054,7 @@ impl PrintOptions {
     }
 
     #[staticmethod]
-    #[pyo3(name = "repr_depth")]
-    #[args(circuits = "*", end_depth = "3")]
+    #[pyo3(name = "repr_depth", signature=(*circuits, end_depth = 3))]
     pub fn repr_circuits_depth(circuits: Vec<CircuitRc>, end_depth: usize) -> String {
         PrintOptions {
             bijection: false,
@@ -1070,8 +1067,7 @@ impl PrintOptions {
         .expect("depth matcher can't fail + bijection is off")
     }
     #[staticmethod]
-    #[pyo3(name = "print_depth")]
-    #[args(circuits = "*", end_depth = "3")]
+    #[pyo3(name = "print_depth", signature=(*circuits, end_depth = 3))]
     pub fn print_circuits_depth(circuits: Vec<CircuitRc>, end_depth: usize) {
         python_println!("{}", PrintOptions::repr_circuits_depth(circuits, end_depth))
     }
@@ -1119,7 +1115,7 @@ impl PrintOptions {
     }
 
     #[staticmethod]
-    #[args(threshold = "400_000_000")]
+    #[pyo3(signature=(threshold = 400_000_000))]
     pub fn size_threshold_commenter(threshold: usize) -> CircuitCommenter {
         CircuitCommenter::new_dyn(Box::new(move |circ| {
             if circ.info().numel() > BigUint::from(threshold) && !circ.is_array() {
@@ -1131,7 +1127,7 @@ impl PrintOptions {
     }
 
     #[staticmethod]
-    #[args("*", only_arrays = "false")]
+    #[pyo3(signature=(*, only_arrays = false))]
     pub fn dtype_commenter(only_arrays: bool) -> CircuitCommenter {
         CircuitCommenter::new_dyn(Box::new(move |circ| {
             if let Some(dtype) = &circ.info().device_dtype.dtype && !(only_arrays && !circ.is_array()) {
