@@ -114,7 +114,7 @@ impl CircuitNodeAutoName for SetSymbolicShape {
 #[pymethods]
 impl SetSymbolicShape {
     #[new]
-    #[args(name = "None")]
+    #[pyo3(signature=(node, shape, name = None))]
     fn new_py(
         node: CircuitRc,
         shape: Shape,
