@@ -426,8 +426,7 @@ impl StoredCumulantVar {
     }
 
     #[staticmethod]
-    #[pyo3(name = "new_mv")]
-    #[args(higher_cumulants = "Default::default()", uuid = "None", name = "None")]
+    #[pyo3(name = "new_mv", signature=(mean, variance, higher_cumulants = Default::default(), uuid = None, name = None))]
     pub fn new_mv_py(
         mean: CircuitRc,
         variance: CircuitRc,
