@@ -963,7 +963,8 @@ pub fn distribute_once_raw(
     }
 }
 
-#[pyfunction(do_broadcasts = "true", prefix = "None", suffix = "None")]
+#[pyfunction]
+#[pyo3(signature=(einsum, operand_idx, do_broadcasts = true, prefix = None, suffix = None))]
 pub fn distribute_once(
     einsum: &Einsum,
     operand_idx: usize,
