@@ -370,8 +370,7 @@ impl SimpFnSubset {
         Ok(Self(new.clone(), Self::get_simp_fns(&new)))
     }
 
-    #[args(set_vals = "**")]
-    #[pyo3(name = "set")]
+    #[pyo3(name = "set", signature=(**set_vals))]
     pub fn set_py(&self, set_vals: Option<HashMap<String, Option<bool>>>) -> Result<Self> {
         if set_vals.is_none() {
             return Ok(self.clone());
