@@ -24,12 +24,13 @@ pub fn elim_no_input_module(module: &Module) -> Option<CircuitRc> {
     module.nodes.is_empty().then(|| module.spec.circuit.clone())
 }
 
-#[pyfunction(
-    add_suffix_on_remove_unused = "true",
-    use_elim_no_input_module = "true",
-    elim_empty = "false"
-)]
-#[pyo3(name = "deep_module_remove_unused_inputs")]
+#[pyfunction]
+#[pyo3(name = "deep_module_remove_unused_inputs", signature=(
+    circuit,
+    add_suffix_on_remove_unused = true,
+    use_elim_no_input_module = true,
+    elim_empty = false
+))]
 pub fn py_deep_module_remove_unused_inputs(
     circuit: CircuitRc,
     add_suffix_on_remove_unused: bool,
@@ -136,10 +137,8 @@ pub fn module_remove_unused_inputs_op(
     Ok(Some(out))
 }
 
-#[pyfunction(
-    add_suffix_on_remove_unused = "true",
-    use_elim_no_input_module = "true"
-)]
+#[pyfunction]
+#[pyo3(signature=(m, add_suffix_on_remove_unused = true, use_elim_no_input_module = true))]
 pub fn module_remove_unused_inputs(
     m: &Module,
     add_suffix_on_remove_unused: bool,
@@ -171,12 +170,15 @@ pub fn module_strip_args(m: &Module) -> Module {
     )
 }
 
-#[pyfunction(
-    prefix_to_strip = "None",
-    module_name = "None",
-    check_all_inputs_used = "true",
-    check_unique_arg_names = "true"
-)]
+#[pyfunction]
+#[pyo3(signature=(
+    circuit,
+    input_specs,
+    prefix_to_strip = None,
+    module_name = None,
+    check_all_inputs_used = true,
+    check_unique_arg_names = true
+))]
 pub fn extract_rewrite_raw(
     circuit: CircuitRc,
     input_specs: Vec<(CircuitRc, ModuleArgSpec)>,
