@@ -176,7 +176,7 @@ impl Schedule {
         Ok(())
     }
 
-    #[args(allow_missing = "false")]
+    #[pyo3(signature=(map, allow_missing = false))]
     pub fn replace_tensors(
         &self,
         map: HashMap<HashBytes, Tensor>,
@@ -220,7 +220,7 @@ impl Schedule {
         });
         Ok(result)
     }
-    #[args(settings = "Default::default()")]
+    #[pyo3(signature=(settings = Default::default()))]
     pub fn evaluate(&self, settings: OptimizationSettings) -> Result<Tensor> {
         let eval = |timed| -> Result<_> {
             let result = if settings.adjust_numerical_scale {
@@ -274,7 +274,7 @@ impl Schedule {
         Ok(())
     }
 
-    #[args(settings = "Default::default()")]
+    #[pyo3(signature=(settings = Default::default()))]
     pub fn evaluate_many(&self, settings: OptimizationSettings) -> Result<Vec<Tensor>> {
         let single = self.evaluate(settings)?;
         Ok(self.split(single))
