@@ -57,11 +57,12 @@ impl Default for Updater {
 #[pymethods]
 impl Updater {
     #[new]
-    #[args(
-        cache_transform = "Updater::default().cache_transform",
-        cache_update = "Updater::default().cache_update",
-        default_fancy_validate = "Updater::default().default_fancy_validate"
-    )]
+    #[pyo3(signature=(
+        transform,
+        cache_transform = Updater::default().cache_transform,
+        cache_update = Updater::default().cache_update,
+        default_fancy_validate = Updater::default().default_fancy_validate
+    ))]
     pub fn new(
         transform: TransformRc,
         cache_transform: bool,
@@ -231,7 +232,7 @@ impl CircuitLinkedList {
 #[pymethods]
 impl Getter {
     #[new]
-    #[args(default_fancy_validate = "Getter::default().default_fancy_validate")]
+    #[pyo3(signature=(default_fancy_validate = Getter::default().default_fancy_validate))]
     pub fn new(default_fancy_validate: bool) -> Self {
         Self {
             default_fancy_validate,
@@ -651,12 +652,12 @@ impl Default for Expander {
 #[pymethods]
 impl Expander {
     #[new]
-    #[args(
-        expanders = "*",
-        ban_multiple_matches_on_node = "Expander::default().ban_multiple_matches_on_node",
-        default_fancy_validate = "Expander::default().default_fancy_validate",
-        suffix = "None"
-    )]
+    #[pyo3(signature=(
+        *expanders,
+        ban_multiple_matches_on_node = Expander::default().ban_multiple_matches_on_node,
+        default_fancy_validate = Expander::default().default_fancy_validate,
+        suffix = None
+    ))]
     pub fn new(
         expanders: Vec<(IterativeMatcherRc, TransformRc)>,
         ban_multiple_matches_on_node: bool,
@@ -751,7 +752,7 @@ impl Expander {
             .map(|((c, rep), new_matchers)| self_.batch_impl(c, new_matchers, &rep))
             .collect::<Result<_>>()?;
 
-        let expanded = expand_node(circuit.clone(), &new_children, |c, rep, child_idx| {
+        let expanded = expand_node(circuit.clone(), &new_children, &mut |c, rep, child_idx| {
             self_.batch_impl(
                 c,
                 new_matchers_per[child_idx].clone(),
