@@ -142,12 +142,7 @@ macro_rules! py_forward_sample_spec {
             fn get_transform_py(&self) -> TransformRc {
                 self.clone().get_transform()
             }
-            #[pyo3(name = "get_sample_expander")]
-            #[args(
-                var_matcher = "default_var_matcher()",
-                default_fancy_validate = "false",
-                suffix = "\"sample\".to_owned()"
-            )]
+            #[pyo3(name = "get_sample_expander", signature=(var_matcher = default_var_matcher(), default_fancy_validate = false, suffix = "sample".to_owned()))]
             fn get_sample_expander_py(
                 &self,
                 var_matcher: IterativeMatcherRc,
@@ -182,13 +177,13 @@ py_forward_sample_spec!(RandomSampleSpec);
 #[pymethods]
 impl RandomSampleSpec {
     #[new]
-    #[args(
-        shape = "RandomSampleSpec::default().shape",
-        replace = "RandomSampleSpec::default().replace",
-        probs_and_group_evaluation_settings = "RandomSampleSpec::default().probs_and_group_evaluation_settings",
-        simplify = "RandomSampleSpec::default().simplify",
-        seeder = "None"
-    )]
+    #[pyo3(signature=(
+        shape = RandomSampleSpec::default().shape,
+        replace = RandomSampleSpec::default().replace,
+        probs_and_group_evaluation_settings = RandomSampleSpec::default().probs_and_group_evaluation_settings,
+        simplify = RandomSampleSpec::default().simplify,
+        seeder = None
+    ))]
     fn new(
         shape: Shape,
         replace: bool,
@@ -363,7 +358,7 @@ impl Default for RunDiscreteVarAllSpec {
 #[pymethods]
 impl RunDiscreteVarAllSpec {
     #[new]
-    #[args(subsets = "None")]
+    #[pyo3(signature=(groups, subsets = None))]
     fn py_new(
         groups: Vec<CircuitRc>,
         subsets: Option<Vec<Slice>>,
@@ -372,7 +367,7 @@ impl RunDiscreteVarAllSpec {
     }
 
     #[staticmethod]
-    #[args(circuits = "*")]
+    #[pyo3(signature=(*circuits))]
     fn create_full_from_circuits(circuits: Vec<CircuitRc>) -> Result<Self> {
         let mut discrete_vars_groups: HashSet<CircuitRc> = HashSet::default();
         let mut add_all_groups = |circ: CircuitRc| {
@@ -529,13 +524,13 @@ pub struct Sampler {
 #[pymethods]
 impl Sampler {
     #[new]
-    #[args(
-        var_matcher = "default_var_matcher()",
-        cumulant_matcher = "Matcher::types(vec![CircuitType::Cumulant]).into()",
-        suffix = "\"sample\".to_owned()",
-        run_on_sampled = "Transform::ident().rc()",
-        simplify_Sampled = "true"
-    )]
+    #[pyo3(signature=(
+        sample_spec,
+        var_matcher = default_var_matcher(),
+        cumulant_matcher = Matcher::types(vec![CircuitType::Cumulant]).into(),
+        suffix = "sample".to_owned(),
+        run_on_sampled = Transform::ident().rc(),
+    ))]
     fn new(
         sample_spec: SampleSpec,
         var_matcher: IterativeMatcherRc,
