@@ -19,13 +19,16 @@ pub fn traverse_until_depth(depth: Option<u32>) -> IterativeMatcherRc {
 }
 
 // TODO: improve me: fixed operand index isn't very flexible in deep case (though I'm not sure that deep distribute rewrite is that important...)
-#[pyfunction(
-    traversal = "traverse_until_depth(Some(1))",
-    prefix = "None",
-    suffix = "None",
-    allow_partial_distribute = "true",
-    do_broadcasts = "true"
-)]
+#[pyfunction]
+#[pyo3(signature=(
+    einsum,
+    operand_idx,
+    traversal = traverse_until_depth(Some(1)),
+    prefix = None,
+    suffix = None,
+    allow_partial_distribute = true,
+    do_broadcasts = true
+))]
 pub fn distribute(
     einsum: Einsum,
     operand_idx: usize,
