@@ -18,12 +18,14 @@ pub fn default_index_traversal() -> IterativeMatcherRc {
         .rc()
 }
 
-#[pyfunction(
-    traversal = "default_index_traversal()",
-    suffix = "None",
-    allow_partial_pushdown = "false",
-    elim_identity = "true"
-)]
+#[pyfunction]
+#[pyo3(signature=(
+    index,
+    traversal = default_index_traversal(),
+    suffix = None,
+    allow_partial_pushdown = false,
+    elim_identity = true
+))]
 pub fn push_down_index(
     index: Index,
     traversal: IterativeMatcherRc,
