@@ -40,13 +40,16 @@ use rustc_hash::{FxHashMap as HashMap, FxHashSet as HashSet};
 use thiserror::Error;
 use uuid::uuid;
 
-#[pyfunction(
-    prefix_to_strip = "None",
-    module_name = "None",
-    check_all_inputs_used = "true",
-    check_unique_arg_names = "true",
-    circuit_to_arg_spec = "None"
-)]
+#[pyfunction]
+#[pyo3(signature=(
+    circuit,
+    matcher,
+    prefix_to_strip = None,
+    module_name = None,
+    check_all_inputs_used = true,
+    check_unique_arg_names = true,
+    circuit_to_arg_spec = None
+))]
 pub fn extract_rewrite(
     circuit: CircuitRc,
     matcher: IterativeMatcherRc,
@@ -97,11 +100,13 @@ pub struct BindItem {
 #[pymethods]
 impl BindItem {
     #[new]
-    #[args(
-        batchable = "ModuleArgSpec::default().batchable",
-        expandable = "ModuleArgSpec::default().expandable",
-        ban_non_symbolic_size_expand = "ModuleArgSpec::default().ban_non_symbolic_size_expand"
-    )]
+    #[pyo3(signature=(
+        matcher,
+        input_circuit,
+        batchable = ModuleArgSpec::default().batchable,
+        expandable = ModuleArgSpec::default().expandable,
+        ban_non_symbolic_size_expand = ModuleArgSpec::default().ban_non_symbolic_size_expand
+    ))]
     fn new(
         matcher: IterativeMatcherRc,
         input_circuit: CircuitRc,
@@ -140,7 +145,8 @@ pub enum Binder {
     Item(BindItem),
 }
 
-#[pyfunction(binders = "*", check_unique_arg_names = "true", name = "None")]
+#[pyfunction]
+#[pyo3(signature=(spec_circuit, *binders, check_unique_arg_names = true, name = None))]
 pub fn module_new_bind(
     spec_circuit: CircuitRc,
     binders: Vec<Binder>,
@@ -404,7 +410,8 @@ fn_struct!(
     ) -> Option<Name>
 );
 
-#[pyfunction(bind_name = "\"bind\".to_owned()")]
+#[pyfunction]
+#[pyo3(signature=(bind_name = "bind".to_owned()))]
 pub fn default_nested_module_namer(bind_name: String) -> NestedModuleNamer {
     NestedModuleNamer::Dyn(NestedModuleNamerDynStruct(Arc::new(
         move |base_circuit, _, modules, _| {
@@ -493,12 +500,12 @@ enum CircOrGet {
 #[pymethods]
 impl ModulePusher {
     #[new]
-    #[args(
-        flatten_modules = "Self::default().flatten_modules",
-        module_construct_callback = "Self::default().module_construct_callback",
-        bind_encountered_symbols = "Self::default().bind_encountered_symbols",
-        namer = "Self::default().namer"
-    )]
+    #[pyo3(signature=(
+        flatten_modules = Self::default().flatten_modules,
+        module_construct_callback = Self::default().module_construct_callback,
+        bind_encountered_symbols = Self::default().bind_encountered_symbols,
+        namer = Self::default().namer
+    ))]
     pub fn new(
         flatten_modules: bool,
         module_construct_callback: ModuleConstructCallback,
@@ -514,7 +521,7 @@ impl ModulePusher {
         }
     }
 
-    #[args(skip_module = "MatcherData::Always(false).into()")]
+    #[pyo3(signature=(circuit, traversal, skip_module = MatcherData::Always(false).into()))]
     fn __call__(
         &mut self,
         _py: Python<'_>,
@@ -525,7 +532,7 @@ impl ModulePusher {
         self.push_down_modules(circuit, traversal, skip_module)
     }
 
-    #[args(skip_module = "MatcherData::Always(false).into()")]
+    #[pyo3(signature=(circuit, traversal, skip_module = MatcherData::Always(false).into()))]
     pub fn push_down_modules(
         &mut self,
         circuit: CircuitRc,
@@ -537,7 +544,7 @@ impl ModulePusher {
     }
 
     // TODO: fancy validate
-    #[args(skip_module = "MatcherData::Always(false).into()")]
+    #[pyo3(signature=(circuit, get, skip_module = MatcherData::Always(false).into()))]
     pub fn get_push_down_modules(
         &mut self,
         circuit: CircuitRc,
@@ -548,7 +555,7 @@ impl ModulePusher {
             .map(|x| unwrap!(x, CircOrGet::Get))
     }
 
-    #[args(skip_module = "MatcherData::Always(false).into()")]
+    #[pyo3(signature=(circuit, get, skip_module = MatcherData::Always(false).into()))]
     pub fn get_unique_op_push_down_modules(
         &mut self,
         circuit: CircuitRc,
@@ -562,7 +569,7 @@ impl ModulePusher {
         Ok(out.into_iter().next())
     }
 
-    #[args(skip_module = "MatcherData::Always(false).into()")]
+    #[pyo3(signature=(circuit, get, skip_module = MatcherData::Always(false).into()))]
     pub fn get_unique_push_down_modules(
         &mut self,
         circuit: CircuitRc,
@@ -574,11 +581,11 @@ impl ModulePusher {
     }
 
     #[staticmethod]
-    #[args(
-        remove_unused_inputs = "true",
-        add_suffix_on_remove_unused = "false",
-        elim_no_input_modules = "true"
-    )]
+    #[pyo3(signature=(
+        remove_unused_inputs = true,
+        add_suffix_on_remove_unused = false,
+        elim_no_input_modules = true
+    ))]
     pub fn remove_and_elim_callback(
         remove_unused_inputs: bool,
         add_suffix_on_remove_unused: bool,
@@ -594,7 +601,7 @@ impl ModulePusher {
     }
 
     #[staticmethod]
-    #[args(add_suffix_on_remove_unused = "false", elim_no_input_modules = "true")]
+    #[pyo3(signature=(add_suffix_on_remove_unused = false, elim_no_input_modules = true))]
     pub fn remove_unused_callback(
         add_suffix_on_remove_unused: bool,
         elim_no_input_modules: bool,
@@ -890,7 +897,7 @@ impl ModulePusher {
             let out = expand_node(
                 circuit.clone(),
                 &new_children.into_iter().map(|x| x.unwrap()).collect(),
-                |c, rep, child_idx| {
+                &mut |c, rep, child_idx| {
                     rec(
                         self_,
                         c,
@@ -1327,11 +1334,12 @@ impl ModuleConstructUpdateBindings {
     }
 }
 
-#[pyfunction(
-    bind_name = "\"upd_bind\".to_owned()",
-    short_if_not_leaf = "true",
-    keep_name_if_not_leaf = "false"
-)]
+#[pyfunction]
+#[pyo3(signature=(
+    bind_name = "upd_bind".to_owned(),
+    short_if_not_leaf = true,
+    keep_name_if_not_leaf = false
+))]
 pub fn default_update_bindings_nested_namer(
     bind_name: String,
     short_if_not_leaf: bool,
@@ -1359,12 +1367,16 @@ pub fn default_update_bindings_nested_namer(
     )))
 }
 
-#[pyfunction(
-    namer = "default_update_bindings_nested_namer(\"upd_bind\".to_owned(), true, false)",
-    skip_module = "MatcherData::Always(false).into()",
-    run_update_on_new_spec_circuits = "false",
-    flatten_modules = "false"
-)]
+#[pyfunction]
+#[pyo3(signature=(
+    circuit,
+    update,
+    matcher,
+    namer = default_update_bindings_nested_namer("upd_bind".to_owned(), true, false),
+    skip_module = MatcherData::Always(false).into(),
+    run_update_on_new_spec_circuits = false,
+    flatten_modules = false
+))]
 pub fn update_bindings_nested(
     circuit: CircuitRc,
     update: MaybeUpdate,
@@ -1578,11 +1590,14 @@ impl SymbolExtractor {
     }
 }
 
-#[pyfunction(
-    use_elim_no_input_modules = "true",
-    conform_batch_if_needed = "false",
-    traversal = "IterativeMatcher::noop_traversal().rc()"
-)]
+#[pyfunction]
+#[pyo3(signature=(
+    circuit,
+    symbols,
+    use_elim_no_input_modules = true,
+    conform_batch_if_needed = false,
+    traversal = IterativeMatcher::noop_traversal().rc()
+))]
 pub fn extract_symbols(
     circuit: CircuitRc,
     symbols: SymbolSetRc,
@@ -1618,11 +1633,14 @@ pub fn extract_symbols(
     ))
 }
 
-#[pyfunction(
-    use_elim_no_input_modules = "true",
-    conform_batch_if_needed = "false",
-    traversal = "IterativeMatcher::noop_traversal().rc()"
-)]
+#[pyfunction]
+#[pyo3(signature=(
+    circuit,
+    get,
+    use_elim_no_input_modules = true,
+    conform_batch_if_needed = false,
+    traversal = IterativeMatcher::noop_traversal().rc()
+))]
 pub fn extract_symbols_get(
     circuit: CircuitRc,
     get: IterativeMatcherRc,
