@@ -29,7 +29,7 @@ pub struct NestRest {
 #[pymethods]
 impl NestRest {
     #[new]
-    #[args(flat = "false")]
+    #[pyo3(signature=(flat = false))]
     pub fn new(flat: bool) -> Self {
         Self { flat }
     }
@@ -65,12 +65,13 @@ impl Default for NestMatcher {
 #[pymethods]
 impl NestMatcher {
     #[new]
-    #[args(
-        flat = "NestMatcher::default().flat",
-        assert_exists = "NestMatcher::default().assert_exists",
-        assert_unique = "NestMatcher::default().assert_unique",
-        fancy_validate = "NestMatcher::default().fancy_validate"
-    )]
+    #[pyo3(signature=(
+        matcher,
+        flat = NestMatcher::default().flat,
+        assert_exists = NestMatcher::default().assert_exists,
+        assert_unique = NestMatcher::default().assert_unique,
+        fancy_validate = NestMatcher::default().fancy_validate
+    ))]
     pub fn new(
         matcher: IterativeMatcherRc,
         flat: bool,
@@ -205,7 +206,7 @@ macro_rules! nest_spec_for {
         #[pymethods]
         impl PyNestSpecInfo {
             #[new]
-            #[args($($field = "Default::default()",)*)]
+            #[pyo3(signature=(spec, $($field = Default::default(),)*))]
             pub fn new(spec: PyNestSpecMultiple, $($field : MaybeNotSet<$field_ty>,)*) -> Result<Self> {
                 let default_nest_info = NestInfo::default();
                 let NestInfo {
@@ -256,7 +257,8 @@ macro_rules! nest_spec_for {
             }
         }
 
-        #[pyfunction(traversal = "IterativeMatcher::noop_traversal().rc()")]
+        #[pyfunction]
+        #[pyo3(signature=([<$name:snake>], spec, traversal = IterativeMatcher::noop_traversal().rc()))]
         pub fn [<nest_ $name:snake s>](
             [<$name:snake>] : $name,
             spec: PyNestSpecSub, // use sub to disallow top level info which does nothing
@@ -1106,11 +1108,13 @@ where
     let (new_x, _, _) = flatten_impl::<Full>(x.rc(), traversal, vec![])?;
     Ok((**new_x).clone().into_op().unwrap())
 }
-#[pyfunction(traversal = "IterativeMatcher::noop_traversal().rc()")]
+#[pyfunction]
+#[pyo3(signature=(einsum, traversal = IterativeMatcher::noop_traversal().rc()))]
 pub fn einsum_flatten(einsum: Einsum, traversal: IterativeMatcherRc) -> Result<Einsum> {
     flatten_gen::<NestEinsumsFullInfo>(einsum, traversal).map(|x| x.normalize_ints())
 }
-#[pyfunction(traversal = "IterativeMatcher::noop_traversal().rc()")]
+#[pyfunction]
+#[pyo3(signature=(add, traversal = IterativeMatcher::noop_traversal().rc()))]
 pub fn add_flatten(add: Add, traversal: IterativeMatcherRc) -> Result<Add> {
     flatten_gen::<NestAddsFullInfo>(add, traversal)
 }
