@@ -35,8 +35,8 @@ use crate::{
 };
 pub type Shape = Sv<[usize; 4]>; // TODO: maybe this should be struct which preserves invariant that dim shapes >= 0?
 
-#[crate::pyo3::pyfunction(shapes = "*")]
-#[pyo3(name = "broadcast_shapes")]
+#[crate::pyo3::pyfunction]
+#[pyo3(name = "broadcast_shapes", signature = (*shapes))]
 pub fn broadcast_shapes_py(shapes: Vec<Shape>) -> Result<PyShape> {
     broadcast_shapes(&shapes).map(PyShape)
 }
